@@ -1,4 +1,10 @@
 package Lingua::EN::Inflect::Phrase;
+BEGIN {
+  $Lingua::EN::Inflect::Phrase::AUTHORITY = 'cpan:AVAR';
+}
+{
+  $Lingua::EN::Inflect::Phrase::VERSION = '0.17';
+}
 
 use strict;
 use warnings;
@@ -7,6 +13,7 @@ use Lingua::EN::Inflect;
 use Lingua::EN::Inflect::Number;
 use Lingua::EN::Tagger;
 use Lingua::EN::FindNumber '$number_re';
+use Lingua::EN::Number::IsOrdinal 'is_ordinal';
 
 =head1 NAME
 
@@ -14,8 +21,6 @@ Lingua::EN::Inflect::Phrase - Inflect short English Phrases
 
 =cut
 
-our $VERSION = '0.16';
-
 =head1 SYNOPSIS
 
   use Lingua::EN::Inflect::Phrase;
@@ -196,20 +201,22 @@ sub _inflect {
 
     $number = (sort { length $a <=> length $b } map $_||'', ($1, $2, $3, $4, $5))[-1];
 
-    my $tagged_number_re;
+    if (not is_ordinal($number)) {
+      my $tagged_number_re;
 
-    foreach my $num_elem (split /\s+/, $number) {
-      $tagged_number_re .= "\Q$num_elem\E/[A-Z]+\\s*";
-    }
+      foreach my $num_elem (split /\s+/, $number) {
+        $tagged_number_re .= "\Q$num_elem\E/[A-Z]+\\s*";
+      }
 
-    my $tagged_number;
-    ($tagged_number, $pad, $rest) = $tagged =~ m/($tagged_number_re)(\s*)(.*)/;
-    my @tagged_number_pos = ($-[1], $+[1]);
+      my $tagged_number;
+      ($tagged_number, $pad, $rest) = $tagged =~ m/($tagged_number_re)(\s*)(.*)/;
+      my @tagged_number_pos = ($-[1], $+[1]);
 
-    if (length $rest) {
-      substr($tagged, $tagged_number_pos[0], ($tagged_number_pos[1] - $tagged_number_pos[0])) = $number;
-      $want_plural   = 1;
-      $want_singular = 0;
+      if (length $rest) {
+        substr($tagged, $tagged_number_pos[0], ($tagged_number_pos[1] - $tagged_number_pos[0])) = $number;
+        $want_plural   = 1;
+        $want_singular = 0;
+      }
     }
   }
 
